@@ -1,6 +1,6 @@
 package Git::Hooks;
 # ABSTRACT: Framework for implementing Git (and Gerrit) hooks
-$Git::Hooks::VERSION = '1.6.12';
+$Git::Hooks::VERSION = '1.7.0';
 use 5.010;
 use strict;
 use warnings;
@@ -8,7 +8,6 @@ use Carp;
 use Exporter qw/import/;
 use Data::Util qw(:all);
 use Path::Tiny;
-use List::MoreUtils qw/uniq/;
 
 our (@EXPORT, @EXPORT_OK, %EXPORT_TAGS); ## no critic (Modules::ProhibitAutomaticExportation)
 my (%Hooks, @PostHooks);
@@ -140,7 +139,7 @@ sub spawn_external_hook {
             }
         } else {
             # child
-            { exec {$file} ($hook, @args) };
+            { exec {$file} ($hook, @args) }
             restore_output($saved_output);
             die "$prefix: can't exec: $!\n";
         }
@@ -525,16 +524,32 @@ my %prepare_hook = (
 );
 
 ################
+
 # This routine loads every plugin configured in the githooks.plugin
 # option.
 
 sub _load_plugins {
     my ($git) = @_;
 
-    my @enabled_plugins  = map {split} $git->get_config(githooks => 'plugin');
+    my %enabled_plugins  = map {($_ => undef)} map {split} $git->get_config(githooks => 'plugin');
+
+    return unless %enabled_plugins; # no one configured
+
     my %disabled_plugins = map {($_ => undef)} map {split} $git->get_config(githooks => 'disable');
 
-    return unless @enabled_plugins; # no one configured
+    # Remove disabled plugins from the list of enabled ones
+    foreach my $plugin (keys %enabled_plugins) {
+        my ($prefix, $basename) = ($plugin =~ /^(.+::)?(.+)/);
+
+        if (   exists $disabled_plugins{$plugin}
+            || exists $disabled_plugins{$basename}
+            || exists $ENV{$basename} && ! $ENV{$basename}
+        ) {
+            delete $enabled_plugins{$plugin};
+        } else {
+            $enabled_plugins{$plugin} = [$prefix, $basename];
+        }
+    }
 
     # Define the list of directories where we'll look for the hook
     # plugins. First the local directory 'githooks' under the
@@ -547,33 +562,27 @@ sub _load_plugins {
         path($INC{'Git/Hooks.pm'})->parent->child('Hooks'),
     );
 
-    foreach my $plugin (uniq @enabled_plugins) {
-        next if exists $disabled_plugins{$plugin}; # disabled by full name
-        my $prefix = '';
-        if ($plugin =~ s/(.+::)//) {
-            next if exists $disabled_plugins{$plugin}; # disabled by basename
-            $prefix = $1;
-        }
-        next if exists $ENV{$plugin} && ! $ENV{$plugin}; # disabled by environment variable
+    # Load remaining enabled plugins
+    while (my ($key, $plugin) = each %enabled_plugins) {
+        my ($prefix, $basename) = @$plugin;
         my $exit = do {
             if ($prefix) {
                 # It must be a module name
-                eval "require $prefix$plugin"; ## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
+                ## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
+                eval "require $prefix$basename";
             } else {
-                # Otherwise, it's a basename that we must look for
-                # in @plugin_dirs
-                $plugin .= '.pm' unless $plugin =~ /\.p[lm]$/i;
-                my @scripts = grep {-f} map {path($_)->child($plugin)} @plugin_dirs;
-                my $script = shift @scripts
-                    or die __PACKAGE__, ": can't find enabled hook $plugin.\n";
-                $plugin = $script; # for the error messages below
-                do $script;
+                # Otherwise, it's a basename we must look for in @plugin_dirs
+                $basename .= '.pm' unless $basename =~ /\.p[lm]$/i;
+                my @scripts = grep {!-d} map {path($_)->child($basename)} @plugin_dirs;
+                $basename = shift @scripts
+                    or die __PACKAGE__, ": can't find enabled hook $basename.\n";
+                do $basename;
             }
         };
         unless ($exit) {
-            die __PACKAGE__, ": couldn't parse $plugin: $@\n" if $@;
-            die __PACKAGE__, ": couldn't do $plugin: $!\n"    unless defined $exit;
-            die __PACKAGE__, ": couldn't run $plugin\n";
+            die __PACKAGE__, ": couldn't parse $basename: $@\n" if $@;
+            die __PACKAGE__, ": couldn't do $basename: $!\n"    unless defined $exit;
+            die __PACKAGE__, ": couldn't run $basename\n";
         }
     }
 
@@ -633,7 +642,7 @@ sub run_hook {                  ## no critic (Subroutines::ProhibitExcessComplex
             opendir my $dh, $dir
                 or $git->error(__PACKAGE__, ": cannot opendir '$dir'", $!)
                     and next;
-            foreach my $file (grep {-f && -x} map {path($dir)->child($_)} readdir $dh) {
+            foreach my $file (grep {!-d && -x} map {path($dir)->child($_)} readdir $dh) {
                 spawn_external_hook($git, $file, $hook_name, @args)
                     or $git->error(__PACKAGE__, ": error in external hook '$file'");
             }
@@ -683,7 +692,7 @@ Git::Hooks - Framework for implementing Git (and Gerrit) hooks
 
 =head1 VERSION
 
-version 1.6.12
+version 1.7.0
 
 =head1 SYNOPSIS
 
@@ -1107,7 +1116,7 @@ like this:
 
     $ git config --add githooks.plugin CheckLog
 
-This is usefull, for example, to enable some plugins globally and
+This is useful, for example, to enable some plugins globally and
 others locally, per repository.
 
 A plugin may hook itself to one or more hooks. C<CheckJira>, for
@@ -1136,7 +1145,7 @@ your hooks.
 
 =item 3.
 
-In Git::Hooks installation.
+In the Git::Hooks installation.
 
 =back
 
