@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckLog;
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies
-$Git::Hooks::CheckLog::VERSION = '1.6.12';
+$Git::Hooks::CheckLog::VERSION = '1.7.0';
 use 5.010;
 use utf8;
 use strict;
@@ -67,21 +67,21 @@ sub _spell_checker {
                 and return;
 
         $tried_to_check = 1;
-    };
+    }
 
     return Text::SpellChecker->new(text => $msg, %extra_options);
 }
 
-sub check_spelling {
+sub spelling_errors {
     my ($git, $id, $msg) = @_;
 
-    return 1 unless $msg;
+    return 0 unless $msg;
 
-    return 1 unless $git->get_config($CFG => 'spelling');
+    return 0 unless $git->get_config($CFG => 'spelling');
 
     # Check all words comprised of at least three Unicode letters
     my $checker = _spell_checker($git, join("\n", uniq($msg =~ /\b(\p{Cased_Letter}{3,})\b/gi)))
-        or return 0;
+        or return 1;
 
     my $errors = 0;
 
@@ -90,12 +90,13 @@ sub check_spelling {
         $git->error($PKG, "commit $id log has a misspelled word: '$badword'",
                     defined $suggestions[0] ? "suggestions: " . join(', ', @suggestions) : undef,
                 );
+        ++$errors;
     }
 
-    return $errors == 0;
+    return $errors;
 }
 
-sub check_patterns {
+sub pattern_errors {
     my ($git, $id, $msg) = @_;
 
     my $errors = 0;
@@ -112,22 +113,24 @@ sub check_patterns {
         }
     }
 
-    return $errors == 0;
+    return $errors;
 }
 
-sub check_title {
+sub title_errors {
     my ($git, $id, $title) = @_;
 
-    $git->get_config($CFG => 'title-required')
-        or return 1;
-
-    defined $title
-        or $git->error($PKG, "commit $id log needs a title line")
-            and return 0;
+    unless (defined $title and length $title) {
+        if ($git->get_config($CFG => 'title-required')) {
+            $git->error($PKG, "commit $id log needs a title line");
+            return 1;
+        } else {
+            return 0;
+        }
+    }
 
     ($title =~ tr/\n/\n/) == 1
         or $git->error($PKG, "commit $id log title should have just one line")
-            and return 0;
+            and return 1;
 
     my $errors = 0;
 
@@ -153,13 +156,13 @@ sub check_title {
         }
     }
 
-    return $errors == 0;
+    return $errors;
 }
 
-sub check_body {
+sub body_errors {
     my ($git, $id, $body) = @_;
 
-    return 1 unless defined $body && length $body;
+    return 0 unless defined $body && length $body;
 
     if (my $max_width = $git->get_config($CFG => 'body-max-width')) {
         my $toobig = $max_width + 1;
@@ -169,44 +172,49 @@ sub check_body {
                         "commit $id log body lines should be at most $max_width characters wide, but $theseare bigger",
                         join("\n", @biggies),
                     );
-            return 0;
+            return 1;
         }
     }
 
-    return 1;
+    return 0;
 }
 
-sub check_message {
+sub footer_errors {
+    my ($git, $id, $cmsg) = @_;
+
+    my $errors = 0;
+
+    if ($git->get_config($CFG => 'signed-off-by')) {
+        scalar($cmsg->get_footer_values('signed-off-by')) > 0
+            or $git->error($PKG, "commit $id must have a Signed-off-by footer")
+                and ++$errors;
+    }
+
+    return $errors;
+}
+
+sub message_errors {
     my ($git, $commit, $msg) = @_;
 
     # assert(defined $msg)
 
-    my $id = defined $commit ? substr($commit->{commit}, 0, 7) : '';
+    my $id = defined $commit ? $commit->{commit} : '';
 
     my $errors = 0;
 
-    check_spelling($git, $id, $msg) or ++$errors;
+    $errors += spelling_errors($git, $id, $msg);
 
-    check_patterns($git, $id, $msg) or ++$errors;
+    $errors += pattern_errors($git, $id, $msg);
 
     my $cmsg = Git::More::Message->new($msg);
 
-    check_title($git, $id, $cmsg->title) or ++$errors;
+    $errors += title_errors($git, $id, $cmsg->title);
 
-    check_body($git, $id, $cmsg->body) or ++$errors;
+    $errors += body_errors($git, $id, $cmsg->body);
 
-    return $errors == 0;
-}
+    $errors += footer_errors($git, $id, $cmsg);
 
-sub check_patchset {
-    my ($git, $opts) = @_;
-
-    _setup_config($git);
-
-    my $sha1   = $opts->{'--commit'};
-    my $commit = $git->get_commit($sha1);
-
-    return check_message($git, $commit, $commit->{body});
+    return $errors;
 }
 
 sub check_message_file {
@@ -221,7 +229,7 @@ sub check_message_file {
         return 0;
     }
 
-    return check_message($git, undef, $msg);
+    return message_errors($git, undef, $msg) == 0;
 }
 
 sub check_ref {
@@ -230,8 +238,7 @@ sub check_ref {
     my $errors = 0;
 
     foreach my $commit ($git->get_affected_ref_commits($ref)) {
-        check_message($git, $commit, $commit->{body})
-            or ++$errors;
+        $errors += message_errors($git, $commit, $commit->{body});
     }
 
     return $errors == 0;
@@ -255,6 +262,17 @@ sub check_affected_refs {
     return $errors == 0;
 }
 
+sub check_patchset {
+    my ($git, $opts) = @_;
+
+    _setup_config($git);
+
+    my $sha1   = $opts->{'--commit'};
+    my $commit = $git->get_commit($sha1);
+
+    return message_errors($git, $commit, $commit->{body}) == 0;
+}
+
 # Install hooks
 COMMIT_MSG       \&check_message_file;
 UPDATE           \&check_affected_refs;
@@ -277,7 +295,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 1.6.12
+version 1.7.0
 
 =head1 DESCRIPTION
 
@@ -330,7 +348,7 @@ option:
 
     git config --add githooks.plugin CheckLog
 
-=for Pod::Coverage check_spelling check_patterns check_title check_body check_message check_ref
+=for Pod::Coverage spelling_errors pattern_errors title_errors body_errors footer_errors message_errors check_ref
 
 =head1 NAME
 
@@ -407,6 +425,11 @@ The Text::SpellChecker module uses defaults to infer which language it
 must use to spell check the message. You can make it use a particular
 language passing its ISO code to this option.
 
+=head2 githooks.checklog.signed-off-by [01]
+
+This option requires the commit to have at least one C<Signed-off-by>
+footer.
+
 =head1 EXPORTS
 
 This module exports the following routines that can be used directly
