@@ -1,6 +1,6 @@
 package Git::More;
 # ABSTRACT: A Git extension with some goodies for hook developers
-$Git::More::VERSION = '1.6.12';
+$Git::More::VERSION = '1.7.0';
 use strict;
 use warnings;
 
@@ -114,91 +114,103 @@ sub clean_cache {
 sub get_commit {
     my ($git, $commit) = @_;
 
-    local $/ = "\c@\cJ";
-    my ($pipe, $ctx) = $git->command_output_pipe(
-        'rev-list',
-        '--no-walk',
-        # See 'git help rev-list' to understand the --pretty argument
-        '--pretty=format:%H%n%T%n%P%n%aN%n%aE%n%ai%n%cN%n%cE%n%ci%n%s%n%n%b%x00',
-        '--encoding=UTF-8',
-        $commit,
-    );
+    my $cache = $git->cache('commits');
 
-    my $commit_hash;
-    while (<$pipe>) {
+    unless (exists $cache->{$commit}) {
+        local $/ = "\c@\cJ";
+        my ($pipe, $ctx) = $git->command_output_pipe(
+            'rev-list',
+            '--no-walk',
+            # See 'git help rev-list' to understand the --pretty argument
+            '--pretty=format:%H%n%T%n%P%n%aN%n%aE%n%ai%n%cN%n%cE%n%ci%n%G? %GK%n%s%n%n%b%x00',
+            '--encoding=UTF-8',
+            $commit,
+        );
+
+        while (<$pipe>) {
             chomp;
             my %commit;
             @commit{qw/header commit tree parent
                        author_name author_email author_date
-                       commmitter_name committer_email committer_date
-                       body/} = split "\cJ", $_, 11;
-            $commit_hash = \%commit;
+                       committer_name committer_email committer_date
+                       signature body/} = split "\cJ", $_, 12;
+            $cache->{$commit} = \%commit;
+        }
+
+        $git->command_close_pipe($pipe, $ctx);
     }
 
-    $git->command_close_pipe($pipe, $ctx);
-
-    return $commit_hash;
+    return $cache->{$commit};
 }
 
 sub get_commits {
     my ($git, $old_commit, $new_commit) = @_;
 
-    # We're interested in all commits reachable from $new_commit but
-    # not reachable from $old_commit. We're going to use the "git
-    # rev-list" command for that. As you can read on its
-    # documentation, the usual syntax to specify this set of commits
-    # is this: "$new_commit ^$old_commit".
+    my $cache = $git->cache('ranges');
 
-    # However, there are two special cases: when a new branch is
-    # created and when an old branch is deleted.
+    my $range = "$old_commit:$new_commit";
 
-    # When an old branch is deleted $new_commit is null (i.e.,
-    # '0'x40'). In this case previous commits are being forgotten and
-    # the hooks usually don't need to check them. So, in this
-    # situation we simply return an empty list of commits.
+    unless (exists $cache->{$range}) {
+        # We're interested in all commits reachable from $new_commit but not
+        # reachable from $old_commit. We're going to use the "git rev-list"
+        # command for that. As you can read on its documentation, the usual
+        # syntax to specify this set of commits is this: "$new_commit
+        # ^$old_commit".
 
-    return if $new_commit eq $UNDEF_COMMIT;
+        # However, there are two special cases: when a new branch is created
+        # and when an old branch is deleted.
 
-    # When a new branch is created $old_commit is null (i.e.,
-    # '0'x40). In this case we want all commits reachable from
-    # $new_commit but not reachable from any other branch. The syntax
-    # for this is "$new_commit ^$b1 ^$b2 ... ^$bn", i.e., $new_commit
-    # followed by every other branch name prefixed by carets. We can
-    # get at their names using the technique described in, e.g.,
-    # http://stackoverflow.com/questions/3511057/git-receive-update-hooks-and-new-branches.
+        # When an old branch is deleted $new_commit is null (i.e.,
+        # '0'x40'). In this case previous commits are being forgotten and
+        # the hooks usually don't need to check them. So, in this situation
+        # we simply return an empty list of commits.
 
-    # The @excludes variable will hold the list of commits that will
-    # be prefixed with carets in the git rev-list command invokation.
+        return if $new_commit eq $UNDEF_COMMIT;
 
-    my @excludes =
-        $old_commit eq $UNDEF_COMMIT
-        ? grep {$_ ne $new_commit} $git->command(qw:for-each-ref --format=%(objectname) refs/heads/:)
-        : $old_commit;
+        # When a new branch is created $old_commit is null (i.e.,
+        # '0'x40). In this case we want all commits reachable from
+        # $new_commit but not reachable from any other branch. The syntax
+        # for this is "$new_commit ^$b1 ^$b2 ... ^$bn", i.e., $new_commit
+        # followed by every other branch name prefixed by carets. We can get
+        # at their names using the technique described in, e.g.,
+        # http://stackoverflow.com/questions/3511057/git-receive-update-hooks-and-new-branches.
 
-    # The commit list to be returned
-    my @commits;
+        # The @excludes variable will hold the list of commits that will be
+        # prefixed with carets in the git rev-list command invokation.
 
-    local $/ = "\c@\cJ";
-    my ($pipe, $ctx) = $git->command_output_pipe(
-        'rev-list',
-        # See 'git help rev-list' to understand the --pretty argument
-        '--pretty=format:%H%n%T%n%P%n%aN%n%aE%n%ai%n%cN%n%cE%n%ci%n%s%n%n%b%x00',
-        $new_commit,
-        map {"^$_"} @excludes,
-    );
+        my @excludes =
+            $old_commit eq $UNDEF_COMMIT
+                ? grep {$_ ne $new_commit} $git->command(qw:for-each-ref --format=%(objectname) refs/heads/:)
+                    : $old_commit;
 
-    while (<$pipe>) {
+        # The commit list to be returned
+        my @commits;
+
+        local $/ = "\c@\cJ";
+        my ($pipe, $ctx) = $git->command_output_pipe(
+            'rev-list',
+            # See 'git help rev-list' to understand the --pretty argument
+            '--pretty=format:%H%n%T%n%P%n%aN%n%aE%n%ai%n%cN%n%cE%n%ci%n%G? %GK%n%s%n%n%b%x00',
+            '--encoding=UTF-8',
+            $new_commit,
+            map {"^$_"} @excludes,
+        );
+
+        while (<$pipe>) {
             my %commit;
             @commit{qw/header commit tree parent
                        author_name author_email author_date
-                       commmitter_name committer_email committer_date
-                       body/} = split "\cJ", $_, 11;
+                       committer_name committer_email committer_date
+                       signature body/} = split "\cJ", $_, 12;
             push @commits, \%commit;
+        }
+
+        $git->command_close_pipe($pipe, $ctx);
+
+        $cache->{$range} = \@commits;
     }
 
-    $git->command_close_pipe($pipe, $ctx);
-
-    return @commits;
+    return @{$cache->{$range}};
 }
 
 sub get_commit_msg {
@@ -421,6 +433,12 @@ sub get_current_branch {
     return $branch;
 }
 
+sub get_sha1 {
+    my ($git, $rev) = @_;
+
+    return $git->command_oneline(['rev-parse', '--verify', $rev], {STDERR => 0});
+}
+
 sub get_head_or_empty_tree {
     my ($git) = @_;
 
@@ -482,6 +500,14 @@ sub blob {
     return $cache->{$blob}->stringify;
 }
 
+sub file_size {
+    my ($git, $rev, $file) = @_;
+
+    chomp(my $size = $git->command('cat-file', '-s', "$rev:$file"));
+
+    return $size;
+}
+
 sub error {
     my ($git, $prefix, $message, $details) = @_;
     $message =~ s/\n*$//s;    # strip trailing newlines
@@ -537,7 +563,7 @@ Git::More - A Git extension with some goodies for hook developers
 
 =head1 VERSION
 
-version 1.6.12
+version 1.7.0
 
 =head1 SYNOPSIS
 
@@ -639,7 +665,7 @@ This call would return this hash:
         'b' => [2, 3],
     }
 
-If the section don't exist an empty hash is returned. Any key/value
+If the section doesn't exist an empty hash is returned. Any key/value
 added to the returned hash will be available in subsequent invokations
 of C<get_config>.
 
@@ -678,9 +704,10 @@ the C<git help rev-list> document):
         author_name     => %aN: author name
         author_email    => %aE: author email
         author_date     => %ai: author date in ISO8601 format
-        commmitter_name => %cN: committer name
+        committer_name  => %cN: committer name
         committer_email => %cE: committer email
         committer_date  => %ci: committer date in ISO8601 format
+        signature       => %G? %GK: commit signature check status and key
         body            => %B:  raw body (aka commit message)
     }
 
@@ -885,6 +912,16 @@ by the C<git symbolic-ref HEAD> command.
 If the repository is in a dettached head state, i.e., if HEAD points
 to a commit instead of to a branch, the method returns undef.
 
+=head2 get_sha1 REV
+
+This method returns the SHA1 of the commit represented by REV, using the
+command
+
+  git rev-parse --verify REV
+
+It's useful, for instance, to grok the HEAD's SHA1 so that you can pass it
+to the get_commit method.
+
 =head2 get_head_or_empty_tree
 
 This method returns the string "HEAD" if the repository already has
@@ -911,6 +948,11 @@ destroyed.
 Any remaining ARGS are passed as arguments to C<File::Temp::newdir> so that you
 can have more control over the temporary file creation.
 
+=head2 file_size REV FILE
+
+This method returns the size (in bytes) of FILE (a path relative to the
+repository root) in revision REV.
+
 =head2 error PREFIX MESSAGE [DETAILS]
 
 This method should be used by plugins to record consistent error or warning
